@@ -18,12 +18,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import logging
 
 from . import version
-from .base import News
+from .news import News
+from .markets import Markets
 
 __version__ = version.version
 __author__ = "Asep Saputra"
 
+# Configure basic logging for the library
+logging.basicConfig(level=logging.INFO,
+                    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
-__all__ = ['News']
+__all__ = ['News', 'Markets']
